@@ -1,24 +1,48 @@
 package Selenium::Remote::WebElement;
-$Selenium::Remote::WebElement::VERSION = '1.00';
+$Selenium::Remote::WebElement::VERSION = '1.02';
 # ABSTRACT: Representation of an HTML Element used by Selenium Remote Driver
 
 use Moo;
 use Carp qw(carp croak);
 
 
-
 has 'id' => (
-    is => 'rw',
+    is => 'ro',
+    required => 1,
+    coerce => sub {
+        my ($value) = @_;
+        if (ref($value) eq 'HASH') {
+            if (exists $value->{ELEMENT}) {
+                # The JSONWireProtocol web element object looks like
+                #
+                #     { "ELEMENT": $INTEGER_ID }
+                return $value->{ELEMENT};
+            }
+            elsif (exists $value->{'element-6066-11e4-a52e-4f735466cecf'}) {
+                # but the WebDriver spec web element uses a magic
+                # string. See the spec for more information:
+                #
+                # https://www.w3.org/TR/webdriver/#elements
+                return $value->{'element-6066-11e4-a52e-4f735466cecf'};
+            }
+            else {
+                croak 'When passing in an object to the WebElement id attribute, it must have at least one of the ELEMENT or element-6066-11e4-a52e-4f735466cecf keys.';
+            }
+        }
+        else {
+            return $value;
+        }
+    }
 );
 
+
 has 'driver' => (
-    is => 'rw',
+    is => 'ro',
+    required => 1,
     handles => [qw(_execute_command)],
 );
 
 
-
-
 sub click {
     my ($self) = @_;
     my $res = { 'command' => 'clickElement', 'id' => $self->id };
@@ -37,9 +61,15 @@ sub send_keys {
     my ( $self, @strings ) = @_;
     croak "no keys to send" unless scalar @strings >= 1;
     my $res = { 'command' => 'sendKeysToElement', 'id' => $self->id };
-    map { $_ .= "" } @strings;
+
+    # We need to send an array of single characters to be WebDriver
+    # spec compatible. That is, for @strings = ('hel', 'lo'), the
+    # corresponding value must be ('h', 'e', 'l', 'l', 'o' ). This
+    # format conforms with the Spec AND works with the Selenium
+    # standalone server.
+    my $strings = join('', map { $_ .= "" } @strings);
     my $params = {
-        'value' => \@strings,
+        'value' => [ split('', $strings) ]
     };
     return $self->_execute_command( $res, $params );
 }
@@ -187,17 +217,66 @@ Selenium::Remote::WebElement - Representation of an HTML Element used by Seleniu
 
 =head1 VERSION
 
-version 1.00
+version 1.02
 
 =head1 DESCRIPTION
 
-Selenium Webdriver represents all the HTML elements as WebElement. This module
-provides a mechanism to represent them as objects & perform various actions on
-the related elements. This module should not be instantiated directly by the end
-user. Selenium::Remote::Driver instantiates this module when required. Typically,
-the find_element method in Selenium::Remote::Driver returns this object on which
+Selenium Webdriver represents all the HTML elements as WebElements.
+This module provides a mechanism to represent them as objects &
+perform various actions on the related elements. This module should
+not be instantiated directly by the end user. Selenium::Remote::Driver
+instantiates this module when required. Typically, the find_element
+method in Selenium::Remote::Driver returns this object on which
 various element related operations can be carried out.
 
+What is probably most useful on this page is the list of methods below
+that you can perform on an element once you've found one and S::R::D
+has made an instance of this for you.
+
+=head1 ATTRIBUTES
+
+=head2 id
+
+Required: Pass in a string representing the ID of the object. The
+string should be obtained from the response object of making one of
+the C<find_element> calls from L</Selenium::Remote::Driver>.
+
+The attribute is also set up to handle spec compliant element response
+objects via its `coerce` such that any of the following will work and
+are all equivalent:
+
+    my $old_elem = Selenium::Remote::WebElement->new(
+        id => 1,
+        driver => $driver
+    );
+
+    my $new_remote_elem = Selenium::Remote::WebElement->new(
+        id => { ELEMENT => 1 },
+        driver => $driver
+    );
+
+    my $new_spec_elem = Selenium::Remote::WebElement->new(
+        id => { 'element-6066-11e4-a52e-4f735466cecf' => 1 },
+        driver => $driver
+    );
+
+and then after instantiation, all three would give the following for
+`id`:
+
+    print $elem->id; # prints 1
+
+Again, for typical usage of S::R::D and this module, none of this
+matters and it should Just Work without you having to worry about it
+at all. For further reading, the L<W3C
+spec|https://www.w3.org/TR/webdriver/#elements> strictly dictates the
+exact behavior.
+
+=head2 driver
+
+Required: Pass in a Selenium::Remote::Driver instance or one of its
+subclasses. The WebElement needs the appropriate Driver session to
+execute its commands properly.
+
 =head1 FUNCTIONS
 
 =head2 click
@@ -526,7 +605,7 @@ Aditya Ivaturi <ivaturi@gmail.com>
 
 Copyright (c) 2010-2011 Aditya Ivaturi, Gordon Child
 
-Copyright (c) 2014-2015 Daniel Gempesaw
+Copyright (c) 2014-2016 Daniel Gempesaw
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
